@@ -1,6 +1,6 @@
 #' Download, label, deflate and create survey design object for PNADC microdata
 #' @description Core function of package. With this function only, the user can download a PNADC microdata from a year or quarter and get a sample design object ready to use with \code{survey} package functions.
-#' @import survey readr dplyr magrittr RCurl utils timeDate readxl tibble
+#' @import survey readr dplyr magrittr projmgr httr RCurl utils timeDate readxl tibble
 #' @param year The year of the data to be downloaded. Must be a number between 2012 and current year. Vector not accepted.
 #' @param quarter The quarter of the year of the data to be downloaded. Must be number from 1 to 4. Vector not accepted. If \code{NULL}, \code{interview} or \code{topic} number must be provided.
 #' @param interview The interview number of the data to be downloaded. Must be number from 1 to 5. Vector not accepted. Using this option will get annual per interview data. If \code{NULL}, \code{quarter} or \code{topic} number must be provided.
@@ -19,50 +19,64 @@
 #' \donttest{
 #' pnadc.svy <- get_pnadc(year=2017, quarter=4, vars=c("VD4001","VD4002"), defyear=2017, defperiod=4,
 #'                        labels=TRUE, deflator=TRUE, design=TRUE, savedir=tempdir())
-#' survey::svymean(x=~VD4002, design=pnadc.svy, na.rm=TRUE)
+#' if (!is.null(pnadc.svy)) survey::svymean(x=~VD4002, design=pnadc.svy, na.rm=TRUE)
 #' pnadc.svy2 <- get_pnadc(year=2017, interview=5, vars=c("V4112","V4121B"), defyear=2017, defperiod=4,
 #'                         labels=TRUE, deflator=TRUE, design=TRUE, savedir=tempdir())
-#' survey::svymean(x=~V4121B, design=pnadc.svy2, na.rm=TRUE)
+#' if (!is.null(pnadc.svy2)) survey::svymean(x=~V4121B, design=pnadc.svy2, na.rm=TRUE)
 #' pnadc.svy3 <- get_pnadc(year=2017, topic=4, vars=c("S01022","S01025"), defyear=2017, defperiod=4,
 #'                         labels=TRUE, deflator=TRUE, design=TRUE, savedir=tempdir())
-#' survey::svymean(x=~S01022, design=pnadc.svy3, na.rm=TRUE)}
+#' if (!is.null(pnadc.svy3)) survey::svymean(x=~S01022, design=pnadc.svy3, na.rm=TRUE)}
 #' @export
 
 get_pnadc <- function(year, quarter = NULL, interview = NULL, topic = NULL, vars = NULL, defyear = NULL, defperiod = NULL, 
                        labels = TRUE, deflator = TRUE, design = TRUE, savedir = tempdir())
 {
   if (is.null(quarter) & is.null(interview) & is.null(topic)) {
-    stop("Quarter number or interview number or topic number must be provided.")
+    message("Quarter number or interview number or topic number must be provided.")
+    return(NULL)
   }
   if ((!is.null(quarter) & !is.null(interview)) | 
       (!is.null(quarter) & !is.null(topic)) | 
       (!is.null(interview) & !is.null(topic)) | 
       (!is.null(quarter) & !is.null(interview) & !is.null(topic))) {
-    stop("Must be provided only one between quarter number, interview number and topic number.")
+    message("Must be provided only one between quarter number, interview number and topic number.")
+    return(NULL)
   }
   if (year < 2012) {
-    stop("Year must be greater or equal to 2012.")
+    message("Year must be greater or equal to 2012.")
+    return(NULL)
   }
   if (year > timeDate::getRmetricsOptions("currentYear")) {
-    stop("Year cannot be greater than current year.")
+    message("Year cannot be greater than current year.")
+    return(NULL)
   }
   if (!dir.exists(savedir)) {
     savedir <- tempdir()
-    warning(paste0("The directory provided does not exist, so the directory was set to '", tempdir()), "'.")
+    message(paste0("The directory provided does not exist, so the directory was set to '", tempdir()), "'.")
   }
   if (substr(savedir, nchar(savedir), nchar(savedir)) == "/" | substr(savedir, nchar(savedir), nchar(savedir)) == "\\") {
     savedir <- substr(savedir, 1, nchar(savedir)-1)
   }
   if (!is.null(quarter)) {
     if (quarter < 1 | quarter > 4) { 
-      stop("Quarter number must be an integer from 1 to 4.")
+      message("Quarter number must be an integer from 1 to 4.")
+      return(NULL)
     }
     ftpdir <- ("ftp://ftp.ibge.gov.br/Trabalho_e_Rendimento/Pesquisa_Nacional_por_Amostra_de_Domicilios_continua/Trimestral/Microdados/")
+    if (!projmgr::check_internet()) {
+      message("The internet connection is unavailable.")
+      return(NULL)
+    }
+    if (httr::http_error(GET(ftpdir, timeout(60)))) {
+      message("The microdata server is unavailable.")
+      return(NULL)
+    }
     ftpdata <- paste0(ftpdir, year, "/")
     datayear <- unlist(strsplit(gsub("\r\n", "\n", RCurl::getURL(ftpdata, dirlistonly=TRUE)), "\n"))
     dataname <- datayear[which(startsWith(datayear, paste0("PNADC_0", quarter, year)))]
     if (length(dataname) == 0) {
-      stop("Data unavailable for selected quarter and year.")
+      message("Data unavailable for selected quarter and year.")
+      return(NULL)
     }
     docfiles <- unlist(strsplit(gsub("\r\n", "\n", RCurl::getURL(paste0(ftpdir, "Documentacao/"), dirlistonly=TRUE)), "\n"))
     inputzip <- docfiles[which(startsWith(docfiles, "Dicionario_e_input"))]
@@ -86,7 +100,7 @@ get_pnadc <- function(year, quarter = NULL, interview = NULL, topic = NULL, vars
         data_pnadc <- PNADcIBGE::pnadc_labeller(data_pnadc=data_pnadc, dictionary.file=dicfile)
       }
       else {
-        warning("Labeller function is unavailable in package PNADcIBGE.")
+        message("Labeller function is unavailable in package PNADcIBGE.")
       }
     }
     if (deflator == TRUE) {
@@ -99,15 +113,24 @@ get_pnadc <- function(year, quarter = NULL, interview = NULL, topic = NULL, vars
         data_pnadc <- PNADcIBGE::pnadc_deflator(data_pnadc=data_pnadc, deflator.file=deffile)
       }
       else {
-        warning("Deflator function is unavailable in package PNADcIBGE.")
+        message("Deflator function is unavailable in package PNADcIBGE.")
       }
     }
   }
   if (!is.null(interview)) {
     if (interview < 1 | interview > 5) {
-      stop("Interview number must be a integer from 1 to 5.")
+      message("Interview number must be a integer from 1 to 5.")
+      return(NULL)
     }
     ftpdir <- ("ftp://ftp.ibge.gov.br/Trabalho_e_Rendimento/Pesquisa_Nacional_por_Amostra_de_Domicilios_continua/Anual/Microdados/Visita/")
+    if (!projmgr::check_internet()) {
+      message("The internet connection is unavailable.")
+      return(NULL)
+    }
+    if (httr::http_error(GET(ftpdir, timeout(60)))) {
+      message("The microdata server is unavailable.")
+      return(NULL)
+    }
     ftpdata <- paste0(ftpdir, "Visita_", interview, "/Dados/")
     datayear <- unlist(strsplit(gsub("\r\n", "\n", RCurl::getURL(ftpdata, dirlistonly=TRUE)), "\n"))
     yrint_list <- regmatches(datayear, gregexpr("[[:digit:]]+", datayear))
@@ -118,7 +141,8 @@ get_pnadc <- function(year, quarter = NULL, interview = NULL, topic = NULL, vars
       }
     }
     if (length(dataname) == 0) {
-      stop("Data unavailable for selected interview and year.")
+      message("Data unavailable for selected interview and year.")
+      return(NULL)
     }
     docfiles <- unlist(strsplit(gsub("\r\n", "\n", RCurl::getURL(paste0(ftpdir, "Visita_", interview, "/Documentacao/"), dirlistonly=TRUE)), "\n"))
     if (year < 2015) {
@@ -148,7 +172,7 @@ get_pnadc <- function(year, quarter = NULL, interview = NULL, topic = NULL, vars
         data_pnadc <- PNADcIBGE::pnadc_labeller(data_pnadc=data_pnadc, dictionary.file=dicfile)
       }
       else {
-        warning("Labeller function is unavailable in package PNADcIBGE.")
+        message("Labeller function is unavailable in package PNADcIBGE.")
       }
     }
     if (deflator == TRUE) {
@@ -156,19 +180,19 @@ get_pnadc <- function(year, quarter = NULL, interview = NULL, topic = NULL, vars
         arcfiles <- unlist(strsplit(gsub("\r\n", "\n", RCurl::getURL(paste0(ftpdir, "Documentacao_Geral/"), dirlistonly=TRUE)), "\n"))
         if (is.null(defyear)) {
           defyear <- timeDate::getRmetricsOptions("currentYear") - 1
-          warning(paste0("Deflator year was not provided, so deflator year was set to ", defyear, "."))
+          message(paste0("Deflator year was not provided, so deflator year was set to ", defyear, "."))
         }
         if (defyear < year) {
           defyear <- year
-          warning(paste0("Deflator year must be greater or equal to microdata year, so deflator year was changed to ", defyear, "."))
+          message(paste0("Deflator year must be greater or equal to microdata year, so deflator year was changed to ", defyear, "."))
         }
         if (defyear < 2017 | defyear >= timeDate::getRmetricsOptions("currentYear")) {
           defyear <- timeDate::getRmetricsOptions("currentYear") - 1
-          warning(paste0("Deflator year must be greater or equal to 2017 and cannot be greater or equal than current year, so deflator year was changed to ", defyear, "."))
+          message(paste0("Deflator year must be greater or equal to 2017 and cannot be greater or equal than current year, so deflator year was changed to ", defyear, "."))
         }
         if (identical(arcfiles[which(startsWith(arcfiles, paste0("deflator_PNADC_", defyear)))], character(0))) {
           defyear <- defyear - 1
-          warning(paste0("Deflator data unavailable for selected year, so deflator year was changed to ", defyear, "."))
+          message(paste0("Deflator data unavailable for selected year, so deflator year was changed to ", defyear, "."))
         }
         defpre <- arcfiles[which(startsWith(arcfiles, paste0("deflator_PNADC_", defyear)))]
         utils::download.file(url=paste0(ftpdir, "Documentacao_Geral/", defpre), destfile=paste0(savedir, "/", defpre), mode="wb")
@@ -178,15 +202,24 @@ get_pnadc <- function(year, quarter = NULL, interview = NULL, topic = NULL, vars
         data_pnadc <- PNADcIBGE::pnadc_deflator(data_pnadc=data_pnadc, deflator.file=deffile)
       }
       else {
-        warning("Deflator function is unavailable in package PNADcIBGE.")
+        message("Deflator function is unavailable in package PNADcIBGE.")
       }
     }
   }
   if (!is.null(topic)) {
     if (topic < 1 | topic > 4) {
-      stop("Topic number must be a integer from 1 to 4.")
+      message("Topic number must be a integer from 1 to 4.")
+      return(NULL)
     }
     ftpdir <- ("ftp://ftp.ibge.gov.br/Trabalho_e_Rendimento/Pesquisa_Nacional_por_Amostra_de_Domicilios_continua/Anual/Microdados/Trimestre/")
+    if (!projmgr::check_internet()) {
+      message("The internet connection is unavailable.")
+      return(NULL)
+    }
+    if (httr::http_error(GET(ftpdir, timeout(60)))) {
+      message("The microdata server is unavailable.")
+      return(NULL)
+    }
     ftpdata <- paste0(ftpdir, "Trimestre_", topic, "/Dados/")
     datayear <- unlist(strsplit(gsub("\r\n", "\n", RCurl::getURL(ftpdata, dirlistonly=TRUE)), "\n"))
     yrint_list <- regmatches(datayear, gregexpr("[[:digit:]]+", datayear))
@@ -197,7 +230,8 @@ get_pnadc <- function(year, quarter = NULL, interview = NULL, topic = NULL, vars
       }
     }
     if (length(dataname) == 0) {
-      stop("Data unavailable for selected topic and year.")
+      message("Data unavailable for selected topic and year.")
+      return(NULL)
     }
     docfiles <- unlist(strsplit(gsub("\r\n", "\n", RCurl::getURL(paste0(ftpdir, "Trimestre_", topic, "/Documentacao/"), dirlistonly=TRUE)), "\n"))
     inputpre <- docfiles[which(startsWith(docfiles, paste0("input_PNADC_trimestre", topic)))]
@@ -221,7 +255,7 @@ get_pnadc <- function(year, quarter = NULL, interview = NULL, topic = NULL, vars
         data_pnadc <- PNADcIBGE::pnadc_labeller(data_pnadc=data_pnadc, dictionary.file=dicfile)
       }
       else {
-        warning("Labeller function is unavailable in package PNADcIBGE.")
+        message("Labeller function is unavailable in package PNADcIBGE.")
       }
     }
     if (deflator == TRUE) {
@@ -230,33 +264,33 @@ get_pnadc <- function(year, quarter = NULL, interview = NULL, topic = NULL, vars
         if (is.null(defyear) | is.null(defperiod)) {
           defyear <- year
           defperiod <- topic
-          warning(paste0("Deflator year or period was not provided, so deflator year was set to ", defyear, " and period was set to ", defperiod, "."))
+          message(paste0("Deflator year or period was not provided, so deflator year was set to ", defyear, " and period was set to ", defperiod, "."))
         }
         if (defyear < year) {
           defyear <- year
-          warning(paste0("Deflator year must be greater or equal to microdata year, so deflator year was changed to ", defyear, "."))
+          message(paste0("Deflator year must be greater or equal to microdata year, so deflator year was changed to ", defyear, "."))
         }
         if (defyear == 2016) {
           defyear <- 2017
-          warning(paste0("There is no Deflator data for 2016, so deflator year was changed to ", defyear, "."))
+          message(paste0("There is no Deflator data for 2016, so deflator year was changed to ", defyear, "."))
         }
         if (defyear < 2017 | defyear > timeDate::getRmetricsOptions("currentYear")) {
           defyear <- year
-          warning(paste0("Deflator year must be greater or equal to 2017 and cannot be greater than current year, so deflator year was changed to ", defyear, "."))
+          message(paste0("Deflator year must be greater or equal to 2017 and cannot be greater than current year, so deflator year was changed to ", defyear, "."))
         }
         if (defyear == year & defperiod < topic) {
           defperiod <- topic
-          warning(paste0("For ", defyear, ", deflator period must be greater or equal to microdata topic, so deflator period was changed to ", defperiod, "."))
+          message(paste0("For ", defyear, ", deflator period must be greater or equal to microdata topic, so deflator period was changed to ", defperiod, "."))
         }
         if (defperiod < 1 | defperiod > 4) {
           defperiod <- topic
-          warning(paste0("Deflator period must be greater or equal to 1 and cannot be greater than 4, so deflator period was changed to ", defperiod, "."))
+          message(paste0("Deflator period must be greater or equal to 1 and cannot be greater than 4, so deflator period was changed to ", defperiod, "."))
         }
         perfiles <- unlist(strsplit(gsub("\r\n", "\n", RCurl::getURL(paste0(ftpdir, "Trimestre_", defperiod, "/Documentacao/"), dirlistonly=TRUE)), "\n"))
         if (identical(perfiles[which(startsWith(perfiles, paste0("deflator_PNADC_", defyear, "_trimestre", defperiod)))], character(0))) {
           defyear <- year
           defperiod <- topic
-          warning(paste0("Deflator data unavailable for selected year and period, so deflator year was changed to ", defyear, " and period was changed to ", defperiod, "."))
+          message(paste0("Deflator data unavailable for selected year and period, so deflator year was changed to ", defyear, " and period was changed to ", defperiod, "."))
         }
         defpre <- perfiles[which(startsWith(perfiles, paste0("deflator_PNADC_", defyear, "_trimestre", defperiod)))]
         utils::download.file(url=paste0(ftpdir, "Trimestre_", defperiod, "/Documentacao/", defpre), destfile=paste0(savedir, "/", defpre), mode="wb")
@@ -266,7 +300,7 @@ get_pnadc <- function(year, quarter = NULL, interview = NULL, topic = NULL, vars
         data_pnadc <- PNADcIBGE::pnadc_deflator(data_pnadc=data_pnadc, deflator.file=deffile)
       }
       else {
-        warning("Deflator function is unavailable in package PNADcIBGE.")
+        message("Deflator function is unavailable in package PNADcIBGE.")
       }
     }
   }
@@ -275,7 +309,7 @@ get_pnadc <- function(year, quarter = NULL, interview = NULL, topic = NULL, vars
       data_pnadc <- PNADcIBGE::pnadc_design(data_pnadc=data_pnadc)
     }
     else {
-      warning("Sample design function is unavailable in package PNADcIBGE.")
+      message("Sample design function is unavailable in package PNADcIBGE.")
     }
   }
   return(data_pnadc)
